# django-calingen

[![GitHub branch checks state](https://img.shields.io/github/actions/workflow/status/mischback/django-calingen/ci-default.yml?branch=development&style=flat&logo=github)](https://github.com/Mischback/django-calingen/actions/workflows/ci-default.yml?query=branch%3Adevelopment)
[![Read the Docs (version)](https://img.shields.io/readthedocs/django-calingen/latest)](https://django-calingen.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://img.shields.io/coveralls/github/Mischback/django-calingen)](https://coveralls.io/github/Mischback/django-calingen)
[![GitHub License](https://img.shields.io/github/license/mischback/imp?style=flat)](https://github.com/Mischback/django-calingen/blob/development/LICENSE)

[![PyPI](https://img.shields.io/pypi/v/django-calingen)](https://pypi.org/project/django-calingen/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-calingen)](https://pypi.org/project/django-calingen/)
[![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-calingen)](https://pypi.org/project/django-calingen/)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Code style: djlint](https://img.shields.io/badge/html%20style-djlint-blue.svg)](https://github.com/Riverside-Healthcare/djlint)
[![CodeFactor Grade](https://img.shields.io/codefactor/grade/github/Mischback/django-calingen)](https://www.codefactor.io/repository/github/mischback/django-calingen)

**django-calingen** is a pluggable Django application to generate analogous,
legacy, paper-based calendar inlays - thus **cal**ender **in**lay **gen**erator.

- **Source**: https://github.com/Mischback/django-calingen
- **Documentation**: https://django-calingen.readthedocs.io/


## Installation and Setup

Installation and Setup of **django-calingen** is provided in the official documentation: [Quickstart](https://django-calingen.readthedocs.io/en/latest/admin-doc.html) / [Step by Step](https://django-calingen.readthedocs.io/en/latest/cookbook/setup_step_by_step.html)


## Contributing

Contributions are always welcome, be it bugs, feature requests or actual code. [See Contribution Guidelines](https://github.com/Mischback/django-calingen/blob/development/.github/CONTRIBUTING.md) to get you started.
